## $Id: level_report.py 14611 2017-03-08 12:05:09Z henrik $
##
## Copyright (C) 2013 Uli Fouquet & Henrik Bettermann
## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.
##
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with this program; if not, write to the Free Software
## Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
##

import grok
from zope.interface import implementer, Interface, Attribute
from waeup.kofa.students.reports.level_report import (
    LevelReport, LevelReportGenerator,
    ILevelReport, LevelReportGeneratorPage,
    LevelReportPDFView)

class CustomLevelReport(LevelReport):

    note = ""

#    note = """
#<br /><br /><br /><br />
#<font size='10'>
#<strong>Note:</strong> This copy is subject to correction for typographical errors and ratification by the departmental board.
#</font>
#"""

    @property
    def signatures(self):
        site = grok.getSite()
        dean = site['faculties'][self.faccode].officer_1
        hod = site['faculties'][self.faccode][self.depcode].officer_1
        if not dean:
            dean = 'Dean of Faculty'
        if not hod:
            hod = 'Head of Department'
        dean = dean.replace(' - ', '<br />')
        hod = hod.replace(' - ', '<br />')
        return [hod, dean]

class CustomLevelReportGenerator(LevelReportGenerator):

    def generate(self, site, faccode=None, depcode=None, certcode=None,
                 session=None, level=None, author=None):
        result = CustomLevelReport(faccode=faccode, depcode=depcode,
            certcode=certcode, session=session, level=level, author=author)
        return result

# Level Report for graduating students only

class GradLevelReport(CustomLevelReport):
    """
    """

    title = 'Summary of Results'

    @property
    def right_footer(self):
        return self.title + ' (graduating students only) - %s -' % self.session

    def _excluded(self, level_obj):
        """
        """
        if level_obj.remark not in (
            'Pass', '3s_rd_s', '2s_2_s', '2s_1_s', '1s_st_s'):
            return True
        return False

class GradLevelReportGenerator(LevelReportGenerator):

    title = 'Graduating Students Summary of Results'
    grok.name('grad_level_report')

    def generate(self, site, faccode=None, depcode=None, certcode=None,
                 session=None, level=None, author=None):
        result = GradLevelReport(faccode=faccode, depcode=depcode,
            certcode=certcode, session=session, level=level, author=author)
        return result

class GradLevelReportGeneratorPage(LevelReportGeneratorPage):

    grok.context(GradLevelReportGenerator)

class GradLevelReportPDFView(LevelReportPDFView):

    grok.context(ILevelReport)
    grok.name('pdf')
    grok.require('waeup.handleReports')
    prefix = 'GradLevelReport'

    def _filename(self):
        return 'GradLevelReport_rno%s_%s.pdf' % (
            self.context.__name__,
            self.context.creation_dt_string)
